@@ -9,10 +9,14 @@
 #include <string.h>
 
 #ifndef DCLVER
-#define DCLVER "dcl-ver.5"
+#define DCLVER "dcl-ver.6.0.2"
 #endif
 
+#ifndef WINDOWS
 void dclvnm_(char *cvname, int Lvname)
+#else
+void DCLVNM(char *cvname, int Lvname)
+#endif
 {
     int minlen, lbuf;
     char *dclver, *buf;
